aboutsummaryrefslogtreecommitdiffstats
path: root/src/nnn.c
diff options
context:
space:
mode:
authorGravatar Arun Prakash Jana <engineerarun@gmail.com>2020-08-15 20:21:22 +0530
committerGravatar Arun Prakash Jana <engineerarun@gmail.com>2020-08-15 20:21:22 +0530
commit8a82c58a2a25242e37ed4814ae39e8fd57eb92e3 (patch)
tree6f08697e8d5e5ba5465c042df0bd514d533c4ab7 /src/nnn.c
parent5fa16dbd1525e2b476b28291ff55473007d9c1e6 (diff)
downloadnnn-8a82c58a2a25242e37ed4814ae39e8fd57eb92e3.tar.gz
More appropriate enum name
Diffstat (limited to 'src/nnn.c')
-rw-r--r--src/nnn.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/nnn.c b/src/nnn.c
index 8a6cb3b..edaf371 100644
--- a/src/nnn.c
+++ b/src/nnn.c
@@ -5841,7 +5841,7 @@ nochange:
&mousetimings[currentmouse]);
mousedent[currentmouse] = cur;
/* Single click just selects, double click falls through to SEL_GOIN */
if ((mousedent[0] != mousedent[1]) ||
(((_ABSSUB(mousetimings[0].tv_sec, mousetimings[1].tv_sec) << 30)
+ (_ABSSUB(mousetimings[0].tv_nsec, mousetimings[1].tv_nsec)))
@@ -5859,7 +5859,7 @@ nochange:
#endif
// fallthrough
case SEL_NAV_IN: // fallthrough
- case SEL_GOIN:
+ case SEL_OPEN:
/* Cannot descend in empty directories */
if (!ndents)
goto begin;
@@ -5893,7 +5893,7 @@ nochange:
}
/* If opened as vim plugin and Enter/^M pressed, pick */
- if (g_state.picker && sel == SEL_GOIN) {
+ if (g_state.picker && sel == SEL_OPEN) {
appendfpath(newpath, mkpath(path, pent->name, newpath));
writesel(pselbuf, selbufpos - 1);
return EXIT_SUCCESS;
@@ -5841,7 +5841,7 @@ nochange:
&mousetimings[currentmouse]);
mousedent[currentmouse] = cur;
- /* Single click just selects, double click falls through to SEL_GOIN */
+ /* Single click just selects, double click falls through to SEL_OPEN */
if ((mousedent[0] != mousedent[1]) ||
(((_ABSSUB(mousetimings[0].tv_sec, mousetimings[1].tv_sec) << 30)